﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Windows.Forms.DataVisualization.Charting;

//波浪类库：驻波类
//袁绪龙，2023-9-3
//为《海洋工程波浪力学》教学演示系统设计
namespace ClassLibraryWave
{
    /// <summary>
    /// 驻波
    /// </summary>
    /// <remarks>从MarchingWave派生</remarks>
    public class StandingWave:MarchingWave
    {
        //入射波和发射波坐标
        private double[] z1, z2;

        /// <summary>
        /// 设置波浪参数
        /// </summary>
        /// <param name="waveH">波高</param>
        /// <param name="waveL">波长</param>
        /// <param name="waveT">周期</param>
        /// <param name="waveDepth">水深</param>
        /// <param name="nPoint">一个波长内的坐标点数，默认40</param>
        /// <param name="nWave">显示的波长数，默认4</param>
        public new void Set(double waveH, double waveL, double waveT, double waveDepth, int nPoint = 40, int nWave = 4)
        {
            base.Set(waveH, waveL, waveT, waveDepth, nPoint, nWave);
            //创建入射波和发射波坐标数组
            z1 = new double[nPoint * nWave + 1];
            z2 = new double[nPoint * nWave + 1];
        }

        /// <summary>
        /// 计算波形数组
        /// </summary>
        /// <param name="t">指定时刻</param>
        public new void Calc(double t)
        {
            this.t = t;
            double dx = L / NPoint;
            for (int i = 0; i < NPoint * NWave + 1; i++)
            {
                x[i] = i * dx;
                z1[i] = a * Math.Cos(k * x[i] - w * t);
                z2[i] = a * Math.Cos(-k * x[i] - w * t);
                z[i] = z1[i] + z2[i];
            }
        }

        /// <summary>
        /// 显示驻波
        /// 显示3个波形，从上到下依次为入射波、发射波和驻波
        /// </summary>
        /// <param name="chart1">图表控件</param>
        public new void Show(Chart chart1)
        {
            chart1.Series[0] .Points.Clear();
            for (int i = 0; i < NPoint * NWave + 1; i++)
            {
                chart1.Series[0].Points.AddXY(x[i], z1[i]+3*H);
            }

            chart1.Series[1].Points.Clear();
            for (int i = 0; i < NPoint * NWave + 1; i++)
            {
                chart1.Series[1].Points.AddXY(x[i], z2[i] + 2*H);
            }

            chart1.Series[2].Points.Clear();
            for (int i = 0; i < NPoint * NWave + 1; i++)
            {
                chart1.Series[2].Points.AddXY(x[i], z[i]);
            }
        }
    }
}
