﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Forms.DataVisualization.Charting;//引用图表控件命名空间

//波浪类库：基类
//袁绪龙，2023-9-3
//为《海洋工程波浪力学》教学演示系统设计
namespace ClassLibraryWave
{
    /// <summary>
    /// 波浪基类
    /// </summary>
    /// <remarks>抽象类，用于定义波浪基本属性和函数接口</remarks>
    public abstract class Wave
    {
        //波浪参数：波高，波长，周期，水深
        protected double H,L,T,d;

        //波面方程参数：波幅，波数，波频，时间
        protected double a,k,w,t;

        //水质点轨迹参数：质点位置x0,z0[],当前位置x[],z[],
        protected double x0;
        protected double[] z0;

        //波面和质点轨迹仿真结果
        protected double[] x,z,xt,zt;

        //波面和质点估计离散参数：一个波长内的坐标点数，显示的波长数，显示的质点轨迹数
        protected int nPoint, nWave, nTraj;

        //质点轨迹数
        public int NTraj
        {
            get { return nTraj; }
            set { nTraj = value; }
        }

        //波长数
        public int NWave
        {
            get { return nWave; }
            set { nWave = value; }
        }

        //一个波长内的坐标点数
        public int NPoint
        {
            get { return nPoint; }
            set { nPoint = value; }
        }

        /// <summary>
        /// 设置
        /// </summary>
        /// <remarks>抽象方法，用于定义统一接口</remarks>
        /// <param name="waveH">波高</param>
        /// <param name="waveL">波长</param>
        /// <param name="waveT">周期</param>
        /// <param name="waveDepth">水深</param>
        /// <param name="nPoint">波形坐标点数</param>
        /// <param name="nWave">计算波长数</param>
        public abstract void Set(double waveH, double waveL, double waveT, double waveDepth, int nPoint, int nWave);

        /// <summary>
        /// 计算波形数组
        /// </summary>
        /// <remarks>抽象方法，用于定义统一接口</remarks>
        /// <param name="t">当前时刻</param>
        public abstract void Calc(double t);

        /// <summary>
        /// 显示波面曲线
        /// </summary>
        /// <param name="chart1">图表控件</param>
        public abstract void Show(Chart chart1);

        /// <summary>
        /// 显示水质点轨迹曲线
        /// </summary>
        /// <remarks>抽象方法，用于定义统一接口</remarks>
        /// <param name="seri">图表控件</param>
        public abstract void ShowTraj(Chart chart1);

        /// <summary>
        /// 设置轨迹参数
        /// </summary>
        /// <remarks>抽象方法，用于定义统一接口</remarks>
        /// <param name="x0">质点位置</param>
        /// <param name="nTraj">质点数量</param>
        public abstract void SetTraj(double x0, int nTraj);

        /// <summary>
        /// 计算轨迹坐标
        /// </summary>
        /// <remarks>抽象方法，用于定义统一接口</remarks>
        /// <param name="t">当前时间</param>
        public abstract void CalcTraj(double t);
    }
}
