﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Windows.Forms.DataVisualization.Charting;

//波浪类库:波群类
//袁绪龙，2023-9-3
//为《海洋工程波浪力学》教学演示系统设计
namespace ClassLibraryWave
{

    /// <summary>
    /// 波群
    /// </summary>
    /// <remarks>从MarchingWave派生</remarks>
    public class WaveGroup:MarchingWave
    {
        private double dk=0.2, dw=0.2;
        private double[] z1,z2,z3;

        /// <summary>
        /// 设置
        /// </summary>
        /// <param name="waveH"></param>
        /// <param name="waveL"></param>
        /// <param name="waveT"></param>
        /// <param name="waveDepth"></param>
        /// <param name="nPoint"></param>
        /// <param name="nWave"></param>
        public override void Set(double waveH, double waveL, double waveT, double waveDepth, int nPoint = 40, int nWave = 8)
        {
            base.Set(waveH, waveL, waveT, waveDepth, nPoint, nWave);
            //创建波1、波2和波包线坐标数组
            z1 = new double[nPoint * nWave + 1];
            z2 = new double[nPoint * nWave + 1];
            z3 = new double[nPoint * nWave + 1];
        }

        /// <summary>
        /// 计算波形数组
        /// </summary>
        /// <remarks>抽象方法，用于定义统一接口</remarks>
        /// <param name="t">当前时刻</param>
        public override void Calc(double t)
        {
            this.NPoint = NPoint;
            this.NWave = NWave;
            this.t = t;
            int num = NPoint * NWave + 1;
            x = new double[num];
            z = new double[num];
            z1 = new double[num];
            z2 = new double[num];
            z3 = new double[num];
            double dx = L / NPoint;
            for (int i = 0; i < num; i++)
            {
                x[i] = dx * i;
                z1[i] = 0.5*H * Math.Cos(k * x[i] - w * t);
                z2[i] = 0.5 * H * Math.Cos(k*(1+dk) * x[i] - w*(1+dw) * t);
                z[i] = z1[i] + z2[i];
                z3[i] = 2 * a * Math.Cos(k*dk/2 * x[i] - w*dw/2 * t);
            }
        }

        /// <summary>
        /// 显示波形曲线
        /// </summary>
        /// <param name="seri1"></param>
        /// <param name="seri2"></param>
        /// <param name="seri3"></param>
        public override void Show(Chart chart1)
        {
            int num = NPoint * NWave + 1;
            chart1.Series[0].Points.Clear();
            for (int i = 0; i < num; i++)
            {
                chart1.Series[0].Points.AddXY(x[i], z1[i] + 3 * H);
            }

            chart1.Series[1].Points.Clear();
            for (int i = 0; i < num; i++)
            {
                chart1.Series[1].Points.AddXY(x[i], z2[i] + 2 * H);
            }

            chart1.Series[2].Points.Clear();
            for (int i = 0; i < num; i++)
            {
                chart1.Series[2].Points.AddXY(x[i], z[i]);
            }

            chart1.Series[3].Points.Clear();
            for (int i = 0; i < num; i++)
            {
                chart1.Series[3].Points.AddXY(x[i], z3[i]);
            }
        }
    }
}
