﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using ClassLibraryWave;
using System.Windows.Forms.DataVisualization.Charting;

namespace Wave2023
{
    public partial class Form1 : Form
    {
        //定义
        private MarchingWave wave1;
        private StandingWave wave2;
        private WaveGroup wave3;

        public Form1()
        {
            InitializeComponent();
            wave1 = new MarchingWave();
            wave2 = new StandingWave();
            wave3 = new WaveGroup();

        }

        private void Form1_Load(object sender, EventArgs e)
        {
            
            //图表控件初始化
            chart1.ChartAreas[0].AxisX.Title = "x(m)";
            chart1.ChartAreas[0].AxisY.Title = "z(m)";
            chart1.ChartAreas[0].AxisX.MajorTickMark.TickMarkStyle = TickMarkStyle.InsideArea;
            chart1.ChartAreas[0].AxisY.MajorTickMark.TickMarkStyle = TickMarkStyle.InsideArea;
            chart1.ChartAreas[0].AxisX.MajorGrid.LineDashStyle = ChartDashStyle.Dot;
            chart1.ChartAreas[0].AxisY.MajorGrid.LineDashStyle = ChartDashStyle.Dot;
            chart1.ChartAreas[0].AxisX.MajorGrid.LineColor = Color.Gray;
            chart1.ChartAreas[0].AxisY.MajorGrid.LineColor = Color.Gray;

            //初始化参数
            chart1.Series.Clear();
            chart1.Series.Add("二维行进波");
            chart1.Series[0].ChartType = SeriesChartType.Line;
            textBoxH.Text = "1.0";
            textBoxL.Text = "50";
            textBoxT.Text = "5";
            textBoxDepth.Text = "10";
        }

        private void button1_Click(object sender, EventArgs e)
        {
            //第一步：赋值
            double H = Convert.ToDouble(textBoxH.Text);
            double L = Convert.ToDouble(textBoxL.Text);
            double T = Convert.ToDouble(textBoxT.Text);
            double d = Convert.ToDouble(textBoxDepth.Text);

            if (radioButton1.Checked)
            {
                wave1.Set(H, L, T, d);
                wave1.Calc(0);
                wave1.Show(chart1);
            }

            if (radioButton2.Checked)
            {
                wave2.Set(H, L, T, d);
                wave2.Calc(0);
                wave2.Show(chart1);
            }

            if (radioButton3.Checked)
            {
                wave3.Set(H, L, T, d);
                wave3.Calc(0);
                wave3.Show(chart1);
            }

        }

        private double t=0;
        /// <summary>
        /// 启用/停用动态绘图
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void checkBox1_CheckedChanged(object sender, EventArgs e)
        {
            if (checkBox1.Checked)
            {
                timer1.Enabled = true;
            }
            else
            {
                timer1.Enabled = false;
            }
        }

        /// <summary>
        /// 定时事件
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void timer1_Tick(object sender, EventArgs e)
        {
            //更新时间
            t += 0.1;

            //更新波形
            if (radioButton1.Checked)
            {
                wave1.Calc(t);
                wave1.Show(chart1);
                if (checkBox2.Checked)
                {
                    wave1.CalcTraj(t);
                    wave1.ShowTraj(chart1);
                }
            }

            if (radioButton2.Checked)
            {
                wave2.Calc(t);
                wave2.Show(chart1);
            }

            if (radioButton3.Checked)
            {
                wave3.Calc(t);
                wave3.Show(chart1);
            }
        }

        private void radioButton2_CheckedChanged(object sender, EventArgs e)
        {
            chart1.Series.Clear();
            chart1.Series.Add("入射波");
            chart1.Series.Add("反射波");
            chart1.Series.Add("驻波");
            for (int i = 0; i < chart1.Series.Count; i++)
            {
                chart1.Series[i].ChartType = SeriesChartType.Line;
            }
            t = 0;

            //第一步：赋值
            double H = Convert.ToDouble(textBoxH.Text);
            double L = Convert.ToDouble(textBoxL.Text);
            double T = Convert.ToDouble(textBoxT.Text);
            double d = Convert.ToDouble(textBoxDepth.Text);
            wave2.Set(H, L, T, d, 40, 4);

            //第二部：计算波面坐标
            wave2.Calc(0);

            //第三步：显示波面曲线
            wave2.Show(chart1);
            chart1.ChartAreas[0].AxisX.Minimum = 0;
            chart1.ChartAreas[0].AxisY.Minimum = -1 * H;
            chart1.ChartAreas[0].AxisY.Maximum = 4 * H;

        }

        private void radioButton1_CheckedChanged(object sender, EventArgs e)
        {
            chart1.Series.Clear();
            chart1.Series.Add("二维行进波");
            for (int i = 0; i < chart1.Series.Count; i++)
            {
                chart1.Series[i].ChartType = SeriesChartType.Line;
            }
            t = 0;

            //第一步：赋值
            double H = Convert.ToDouble(textBoxH.Text);
            double L = Convert.ToDouble(textBoxL.Text);
            double T = Convert.ToDouble(textBoxT.Text);
            double d = Convert.ToDouble(textBoxDepth.Text);
            wave1.Set(H, L, T, d, 40, 2);

            //第二部：计算波面坐标
            wave1.Calc(0);

            //第三步：显示波面曲线
            wave1.Show(chart1);
            chart1.ChartAreas[0].AxisX.Minimum = 0;
            chart1.ChartAreas[0].AxisX.Maximum = double.NaN;
            chart1.ChartAreas[0].AxisY.Minimum = -1 * H;
            chart1.ChartAreas[0].AxisY.Maximum = 1 * H;


        }

        private void radioButton3_CheckedChanged(object sender, EventArgs e)
        {
            chart1.Series.Clear();
            chart1.Series.Add("波1");
            chart1.Series.Add("波2");
            chart1.Series.Add("波群");
            chart1.Series.Add("波包线");
            for (int i = 0; i < chart1.Series.Count; i++)
            {
                chart1.Series[i].ChartType = SeriesChartType.Line;
            }
            t = 0;

            //第一步：赋值
            double H = Convert.ToDouble(textBoxH.Text);
            double L = Convert.ToDouble(textBoxL.Text);
            double T = Convert.ToDouble(textBoxT.Text);
            double d = Convert.ToDouble(textBoxDepth.Text);
            wave3.Set(H, L, T, d);

            //第二部：计算波面坐标
            wave3.Calc(0);

            //第三步：显示波面曲线
            wave3.Show(chart1);
            chart1.ChartAreas[0].AxisX.Minimum = 0;
            chart1.ChartAreas[0].AxisY.Minimum = -1 * H;
            chart1.ChartAreas[0].AxisY.Maximum = 4 * H;
        }

        private void checkBox2_CheckedChanged(object sender, EventArgs e)
        {
            if (checkBox2.Checked)
            {
                if (radioButton1.Checked)
                {
                    wave1.NWave = 1;
                    wave1.SetTraj();
                    for (int i = 0; i < 5; i++)
                    {
                        chart1.Series.Add("质点轨迹" + i.ToString());
                        chart1.Series.Last().ChartType = SeriesChartType.Line;
                    }
                    double L = Convert.ToDouble(textBoxL.Text);
                    double H = Convert.ToDouble(textBoxH.Text);
                    double d = Convert.ToDouble(textBoxDepth.Text);
                    double w1 = chart1.Size.Width * chart1.ChartAreas[0].Position.Width / 100 * chart1.ChartAreas[0].InnerPlotPosition.Width / 100;
                    double h1 = chart1.Size.Height * chart1.ChartAreas[0].Position.Height / 100 * chart1.ChartAreas[0].InnerPlotPosition.Height / 100;
                    double w2 = (d + 2*H) / h1 * w1;
                    chart1.ChartAreas[0].AxisX.Minimum = 0.25 * L - Math.Ceiling(w2) / 2.0;
                    chart1.ChartAreas[0].AxisX.Maximum = 0.25 * L + 0.5 * Math.Ceiling(w2);
                    chart1.ChartAreas[0].AxisY.Minimum = -d - Math.Ceiling(H);
                    chart1.ChartAreas[0].AxisY.Maximum = Math.Ceiling(H);

                }
            }
            else
            {
                if (radioButton1.Checked)
                {
                    radioButton1_CheckedChanged(sender, e);
                }
                if (radioButton2.Checked)
                {
                    radioButton2_CheckedChanged(sender, e);
                }
                if (radioButton3.Checked)
                {
                    radioButton3_CheckedChanged(sender, e);
                }

            }
        }

        /// <summary>
        /// 设为深水
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void button2_Click(object sender, EventArgs e)
        {
            //深度设为0.5倍波长
            double L=Convert.ToDouble(textBoxL.Text);
            textBoxDepth.Text = (0.5 * L).ToString("0.0");
            checkBox2.Checked = false;
        }

        /// <summary>
        /// 设为有限水深
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void button3_Click(object sender, EventArgs e)
        {
            //深度设为0.1倍波长
            double L = Convert.ToDouble(textBoxL.Text);
            textBoxDepth.Text = (0.1 * L).ToString("0.0");
            checkBox2.Checked = false;
        }

        /// <summary>
        /// 设为浅水
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void button4_Click(object sender, EventArgs e)
        {
            //深度设为0.05倍波长
            double L = Convert.ToDouble(textBoxL.Text);
            textBoxDepth.Text = (0.05 * L).ToString("0.0");
            checkBox2.Checked = false;
        }
    }
}
